@@ -18,28 +18,16 @@
 #ifndef REMOTELISTMODEL_H
 #define REMOTELISTMODEL_H
 
-#include <QStringListModel>
+#include "selectionmodel.h"
 
-class RemoteListModel : public QStringListModel
+class RemoteListModel : public SelectionModel
 {
     Q_OBJECT
 
-    Q_PROPERTY(int count READ rowCount NOTIFY countChanged)
-
 public:
     explicit RemoteListModel(QObject *parent = 0);
-    ~RemoteListModel();
-
-#if QT_VERSION >= 0x050000
-    QHash<int, QByteArray> roleNames() const;
-#endif
-
-signals:
-    void countChanged(int count);
 
 private:
-    QHash<int, QByteArray> m_roleNames;
-
     Q_DISABLE_COPY(RemoteListModel)
 };
 
