@@ -23,7 +23,7 @@
 #include "settingsdialog.h"
 #include "aboutdialog.h"
 #include "valueselectoraction.h"
-#include "../controls/widgets/remotepagestack.h"
+#include "controls/remotepagestack.h"
 #include "../base/remotelistmodel.h"
 #include "../base/scriptengine.h"
 #include "../base/settings.h"
