@@ -21,7 +21,7 @@
 #include <QMaemo5ValueButton>
 
 class QMaemo5ListPickSelector;
-class QAbstractItemModel;
+class SelectionModel;
 
 class ValueSelector : public QMaemo5ValueButton
 {
@@ -31,8 +31,8 @@ public:
     explicit ValueSelector(const QString &text, QWidget *parent = 0);
     ~ValueSelector();
 
-    QAbstractItemModel* model() const;
-    virtual void setModel(QAbstractItemModel *model);
+    SelectionModel* model() const;
+    virtual void setModel(SelectionModel *model);
     
     virtual QVariant currentValue() const;
     virtual void setValue(const QVariant &value);
@@ -44,7 +44,7 @@ signals:
     void valueChanged(const QVariant &value);
 
 protected:
-    QAbstractItemModel *m_model;
+    SelectionModel *m_model;
     QMaemo5ListPickSelector *m_selector;
 
     Q_DISABLE_COPY(ValueSelector)
