@@ -20,7 +20,7 @@
 
 #include <QWidgetAction>
 
-class QAbstractItemModel;
+class SelectionModel;
 
 class ValueSelectorAction : public QWidgetAction
 {
@@ -30,8 +30,8 @@ public:
     explicit ValueSelectorAction(QWidget *parent = 0);
     ~ValueSelectorAction();
 
-    QAbstractItemModel* model() const;
-    void setModel(QAbstractItemModel *model);
+    SelectionModel* model() const;
+    void setModel(SelectionModel *model);
 
     QVariant value() const;
 
@@ -44,7 +44,7 @@ signals:
     void valueChanged(const QVariant &value);
 
 protected:
-    QAbstractItemModel *m_model;
+    SelectionModel *m_model;
     QVariant m_value;
 
 private:
