@@ -20,6 +20,14 @@
 
 #include <QObject>
 #include <QScriptable>
+#include <qmobilityglobal.h>
+#include <QBluetoothSocket>
+
+QTM_BEGIN_NAMESPACE
+class QBluetoothTransferReply;
+QTM_END_NAMESPACE
+
+QTM_USE_NAMESPACE
 
 class BluetoothPrivate;
 
@@ -35,6 +43,10 @@ public:
 
 public slots:
     void discoverDevices();
+    void discoverServices();
+
+    void send(const QString &address, const QString &data);
+    void sendFile(const QString &address, const QString &path);
 
 private:
     Bluetooth(BluetoothPrivate &dd, QObject *parent = 0);
@@ -47,6 +59,13 @@ private:
     Q_DECLARE_PRIVATE(Bluetooth)
 
     Q_PRIVATE_SLOT(d_func(), void _q_onDeviceDiscoveryFinished())
+    Q_PRIVATE_SLOT(d_func(), void _q_onServiceDiscoveryFinished())
+    Q_PRIVATE_SLOT(d_func(), void _q_onSocketConnected())
+    Q_PRIVATE_SLOT(d_func(), void _q_onSocketDisconnected())
+    Q_PRIVATE_SLOT(d_func(), void _q_onSocketReadyRead())
+    Q_PRIVATE_SLOT(d_func(), void _q_onSocketStateChanged(QBluetoothSocket::SocketState))
+    Q_PRIVATE_SLOT(d_func(), void _q_onSocketError(QBluetoothSocket::SocketError))
+    Q_PRIVATE_SLOT(d_func(), void _q_onReplyFinished(QBluetoothTransferReply*))
 };
 
 #endif // BLUETOOTH_H
