@@ -19,14 +19,17 @@
 #define BLUETOOTH_P_H
 
 #include "bluetooth.h"
-#include <qmobilityglobal.h>
 
 QTM_BEGIN_NAMESPACE
 class QBluetoothDeviceDiscoveryAgent;
+class QBluetoothServiceDiscoveryAgent;
+class QBluetoothTransferManager;
 QTM_END_NAMESPACE
 
 QTM_USE_NAMESPACE
 
+class QFile;
+
 class BluetoothPrivate
 {
 
@@ -35,10 +38,24 @@ public:
     virtual ~BluetoothPrivate();
 
     void _q_onDeviceDiscoveryFinished();
+    void _q_onServiceDiscoveryFinished();
+    void _q_onSocketConnected();
+    void _q_onSocketDisconnected();
+    void _q_onSocketReadyRead();
+    void _q_onSocketStateChanged(QBluetoothSocket::SocketState state);
+    void _q_onSocketError(QBluetoothSocket::SocketError error);
+    void _q_onReplyFinished(QBluetoothTransferReply *reply);
 
     Bluetooth *q_ptr;
 
-    QBluetoothDeviceDiscoveryAgent *agent;
+    QBluetoothDeviceDiscoveryAgent *deviceAgent;
+    QBluetoothServiceDiscoveryAgent *serviceAgent;
+
+    QBluetoothSocket *socket;
+
+    QBluetoothTransferManager *manager;
+
+    QFile *file;
 
     Q_DECLARE_PUBLIC(Bluetooth)
 };
